# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleFormulaCreatorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index_data_id': 'int',
        'column_indexes': 'list[int]',
        'description': 'str',
        'formula': 'str',
        'identity_id': 'str',
        'name': 'str',
        'parameters': 'list[str]',
        'permission_string': 'str',
        'scoped_to': 'str'
    }

    attribute_map = {
        'column_index_data_id': 'columnIndexDataId',
        'column_indexes': 'columnIndexes',
        'description': 'description',
        'formula': 'formula',
        'identity_id': 'identityId',
        'name': 'name',
        'parameters': 'parameters',
        'permission_string': 'permissionString',
        'scoped_to': 'scopedTo'
    }

    def __init__(self, column_index_data_id=None, column_indexes=None, description=None, formula=None, identity_id=None, name=None, parameters=None, permission_string=None, scoped_to=None):
        """
        ColumnRuleFormulaCreatorInputV1 - a model defined in Swagger
        """

        self._column_index_data_id = None
        self._column_indexes = None
        self._description = None
        self._formula = None
        self._identity_id = None
        self._name = None
        self._parameters = None
        self._permission_string = None
        self._scoped_to = None

        if column_index_data_id is not None:
          self.column_index_data_id = column_index_data_id
        if column_indexes is not None:
          self.column_indexes = column_indexes
        if description is not None:
          self.description = description
        if formula is not None:
          self.formula = formula
        if identity_id is not None:
          self.identity_id = identity_id
        if name is not None:
          self.name = name
        if parameters is not None:
          self.parameters = parameters
        if permission_string is not None:
          self.permission_string = permission_string
        if scoped_to is not None:
          self.scoped_to = scoped_to

    @property
    def column_index_data_id(self):
        """
        Gets the column_index_data_id of this ColumnRuleFormulaCreatorInputV1.
        The optional index of the column that should be used to create the data ID for the formula. The column index is 1-based. If this is provided, created formula may not be unique across the column. Otherwise, a new asset will be created per row.

        :return: The column_index_data_id of this ColumnRuleFormulaCreatorInputV1.
        :rtype: int
        """
        return self._column_index_data_id

    @column_index_data_id.setter
    def column_index_data_id(self, column_index_data_id):
        """
        Sets the column_index_data_id of this ColumnRuleFormulaCreatorInputV1.
        The optional index of the column that should be used to create the data ID for the formula. The column index is 1-based. If this is provided, created formula may not be unique across the column. Otherwise, a new asset will be created per row.

        :param column_index_data_id: The column_index_data_id of this ColumnRuleFormulaCreatorInputV1.
        :type: int
        """

        self._column_index_data_id = column_index_data_id

    @property
    def column_indexes(self):
        """
        Gets the column_indexes of this ColumnRuleFormulaCreatorInputV1.
        The indexes of the columns that should be used as item inputs to the formula. A column index is 1-based

        :return: The column_indexes of this ColumnRuleFormulaCreatorInputV1.
        :rtype: list[int]
        """
        return self._column_indexes

    @column_indexes.setter
    def column_indexes(self, column_indexes):
        """
        Sets the column_indexes of this ColumnRuleFormulaCreatorInputV1.
        The indexes of the columns that should be used as item inputs to the formula. A column index is 1-based

        :param column_indexes: The column_indexes of this ColumnRuleFormulaCreatorInputV1.
        :type: list[int]
        """
        if column_indexes is None:
            raise ValueError("Invalid value for `column_indexes`, must not be `None`")

        self._column_indexes = column_indexes

    @property
    def description(self):
        """
        Gets the description of this ColumnRuleFormulaCreatorInputV1.
        Clarifying information or other plain language description for items created by this rule. An input of just whitespace is equivalent to a null input.

        :return: The description of this ColumnRuleFormulaCreatorInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ColumnRuleFormulaCreatorInputV1.
        Clarifying information or other plain language description for items created by this rule. An input of just whitespace is equivalent to a null input.

        :param description: The description of this ColumnRuleFormulaCreatorInputV1.
        :type: str
        """

        self._description = description

    @property
    def formula(self):
        """
        Gets the formula of this ColumnRuleFormulaCreatorInputV1.
        The formula that represents the body of the function.

        :return: The formula of this ColumnRuleFormulaCreatorInputV1.
        :rtype: str
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this ColumnRuleFormulaCreatorInputV1.
        The formula that represents the body of the function.

        :param formula: The formula of this ColumnRuleFormulaCreatorInputV1.
        :type: str
        """
        if formula is None:
            raise ValueError("Invalid value for `formula`, must not be `None`")

        self._formula = formula

    @property
    def identity_id(self):
        """
        Gets the identity_id of this ColumnRuleFormulaCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :return: The identity_id of this ColumnRuleFormulaCreatorInputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this ColumnRuleFormulaCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :param identity_id: The identity_id of this ColumnRuleFormulaCreatorInputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def name(self):
        """
        Gets the name of this ColumnRuleFormulaCreatorInputV1.
        Human readable name for items created by this rule. Null or whitespace names are not permitted.

        :return: The name of this ColumnRuleFormulaCreatorInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ColumnRuleFormulaCreatorInputV1.
        Human readable name for items created by this rule. Null or whitespace names are not permitted.

        :param name: The name of this ColumnRuleFormulaCreatorInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def parameters(self):
        """
        Gets the parameters of this ColumnRuleFormulaCreatorInputV1.
        Parameters to use in the formula. The position of the parameter should correspond to the position of its input item in the 'columnIndexes' field. Parameters must start with a letter and must be followed by an alphanumeric character, for example 'Sp3'.

        :return: The parameters of this ColumnRuleFormulaCreatorInputV1.
        :rtype: list[str]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this ColumnRuleFormulaCreatorInputV1.
        Parameters to use in the formula. The position of the parameter should correspond to the position of its input item in the 'columnIndexes' field. Parameters must start with a letter and must be followed by an alphanumeric character, for example 'Sp3'.

        :param parameters: The parameters of this ColumnRuleFormulaCreatorInputV1.
        :type: list[str]
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")

        self._parameters = parameters

    @property
    def permission_string(self):
        """
        Gets the permission_string of this ColumnRuleFormulaCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :return: The permission_string of this ColumnRuleFormulaCreatorInputV1.
        :rtype: str
        """
        return self._permission_string

    @permission_string.setter
    def permission_string(self, permission_string):
        """
        Sets the permission_string of this ColumnRuleFormulaCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :param permission_string: The permission_string of this ColumnRuleFormulaCreatorInputV1.
        :type: str
        """

        self._permission_string = permission_string

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ColumnRuleFormulaCreatorInputV1.
        The ID of the workbook to which this item will be scoped. Null if the item should be globally scoped.

        :return: The scoped_to of this ColumnRuleFormulaCreatorInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ColumnRuleFormulaCreatorInputV1.
        The ID of the workbook to which this item will be scoped. Null if the item should be globally scoped.

        :param scoped_to: The scoped_to of this ColumnRuleFormulaCreatorInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleFormulaCreatorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ValidateCronListInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'next_valid_time_after': 'str',
        'schedules': 'list[str]',
        'timezone': 'str'
    }

    attribute_map = {
        'next_valid_time_after': 'nextValidTimeAfter',
        'schedules': 'schedules',
        'timezone': 'timezone'
    }

    def __init__(self, next_valid_time_after=None, schedules=None, timezone=None):
        """
        ValidateCronListInputV1 - a model defined in Swagger
        """

        self._next_valid_time_after = None
        self._schedules = None
        self._timezone = None

        if next_valid_time_after is not None:
          self.next_valid_time_after = next_valid_time_after
        if schedules is not None:
          self.schedules = schedules
        if timezone is not None:
          self.timezone = timezone

    @property
    def next_valid_time_after(self):
        """
        Gets the next_valid_time_after of this ValidateCronListInputV1.
        The time used to evaluate the next run time. Defaults to the current datetime

        :return: The next_valid_time_after of this ValidateCronListInputV1.
        :rtype: str
        """
        return self._next_valid_time_after

    @next_valid_time_after.setter
    def next_valid_time_after(self, next_valid_time_after):
        """
        Sets the next_valid_time_after of this ValidateCronListInputV1.
        The time used to evaluate the next run time. Defaults to the current datetime

        :param next_valid_time_after: The next_valid_time_after of this ValidateCronListInputV1.
        :type: str
        """

        self._next_valid_time_after = next_valid_time_after

    @property
    def schedules(self):
        """
        Gets the schedules of this ValidateCronListInputV1.
        The list of Quartz cron expressions to validate (see http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :return: The schedules of this ValidateCronListInputV1.
        :rtype: list[str]
        """
        return self._schedules

    @schedules.setter
    def schedules(self, schedules):
        """
        Sets the schedules of this ValidateCronListInputV1.
        The list of Quartz cron expressions to validate (see http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :param schedules: The schedules of this ValidateCronListInputV1.
        :type: list[str]
        """
        if schedules is None:
            raise ValueError("Invalid value for `schedules`, must not be `None`")

        self._schedules = schedules

    @property
    def timezone(self):
        """
        Gets the timezone of this ValidateCronListInputV1.
        The timezone in which to do the time evaluation. Defaults to UTC

        :return: The timezone of this ValidateCronListInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ValidateCronListInputV1.
        The timezone in which to do the time evaluation. Defaults to UTC

        :param timezone: The timezone of this ValidateCronListInputV1.
        :type: str
        """

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ValidateCronListInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemBatchOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'item_updates': 'list[ItemUpdateOutputV1]',
        'job_info': 'JobAcceptedOutputV1',
        'status_message': 'str'
    }

    attribute_map = {
        'item_updates': 'itemUpdates',
        'job_info': 'jobInfo',
        'status_message': 'statusMessage'
    }

    def __init__(self, item_updates=None, job_info=None, status_message=None):
        """
        ItemBatchOutputV1 - a model defined in Swagger
        """

        self._item_updates = None
        self._job_info = None
        self._status_message = None

        if item_updates is not None:
          self.item_updates = item_updates
        if job_info is not None:
          self.job_info = job_info
        if status_message is not None:
          self.status_message = status_message

    @property
    def item_updates(self):
        """
        Gets the item_updates of this ItemBatchOutputV1.
        The list of results from item updates. The Nth output corresponds to the Nth input. Note this field will be an empty collection if the request ran as an asynchronous job.

        :return: The item_updates of this ItemBatchOutputV1.
        :rtype: list[ItemUpdateOutputV1]
        """
        return self._item_updates

    @item_updates.setter
    def item_updates(self, item_updates):
        """
        Sets the item_updates of this ItemBatchOutputV1.
        The list of results from item updates. The Nth output corresponds to the Nth input. Note this field will be an empty collection if the request ran as an asynchronous job.

        :param item_updates: The item_updates of this ItemBatchOutputV1.
        :type: list[ItemUpdateOutputV1]
        """

        self._item_updates = item_updates

    @property
    def job_info(self):
        """
        Gets the job_info of this ItemBatchOutputV1.

        :return: The job_info of this ItemBatchOutputV1.
        :rtype: JobAcceptedOutputV1
        """
        return self._job_info

    @job_info.setter
    def job_info(self, job_info):
        """
        Sets the job_info of this ItemBatchOutputV1.

        :param job_info: The job_info of this ItemBatchOutputV1.
        :type: JobAcceptedOutputV1
        """

        self._job_info = job_info

    @property
    def status_message(self):
        """
        Gets the status_message of this ItemBatchOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :return: The status_message of this ItemBatchOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ItemBatchOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :param status_message: The status_message of this ItemBatchOutputV1.
        :type: str
        """

        self._status_message = status_message

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemBatchOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SwapAcrossAssetsSearchV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_include': 'bool',
        'root_asset_id': 'str',
        'search_type': 'str',
        'swap_item_id': 'str'
    }

    attribute_map = {
        'is_include': 'isInclude',
        'root_asset_id': 'rootAssetId',
        'search_type': 'searchType',
        'swap_item_id': 'swapItemId'
    }

    def __init__(self, is_include=None, root_asset_id=None, search_type=None, swap_item_id=None):
        """
        SwapAcrossAssetsSearchV1 - a model defined in Swagger
        """

        self._is_include = None
        self._root_asset_id = None
        self._search_type = None
        self._swap_item_id = None

        if is_include is not None:
          self.is_include = is_include
        if root_asset_id is not None:
          self.root_asset_id = root_asset_id
        if search_type is not None:
          self.search_type = search_type
        if swap_item_id is not None:
          self.swap_item_id = swap_item_id

    @property
    def is_include(self):
        """
        Gets the is_include of this SwapAcrossAssetsSearchV1.
        If true the items found by this configuration will be included in the output, if false then the results will be excluded from the output (even if found by another finder configuration)

        :return: The is_include of this SwapAcrossAssetsSearchV1.
        :rtype: bool
        """
        return self._is_include

    @is_include.setter
    def is_include(self, is_include):
        """
        Sets the is_include of this SwapAcrossAssetsSearchV1.
        If true the items found by this configuration will be included in the output, if false then the results will be excluded from the output (even if found by another finder configuration)

        :param is_include: The is_include of this SwapAcrossAssetsSearchV1.
        :type: bool
        """
        if is_include is None:
            raise ValueError("Invalid value for `is_include`, must not be `None`")

        self._is_include = is_include

    @property
    def root_asset_id(self):
        """
        Gets the root_asset_id of this SwapAcrossAssetsSearchV1.
        Used if finder type is SwapAcrossAssets, this specifies the ID of the root asset whose immediate children will be iterated.

        :return: The root_asset_id of this SwapAcrossAssetsSearchV1.
        :rtype: str
        """
        return self._root_asset_id

    @root_asset_id.setter
    def root_asset_id(self, root_asset_id):
        """
        Sets the root_asset_id of this SwapAcrossAssetsSearchV1.
        Used if finder type is SwapAcrossAssets, this specifies the ID of the root asset whose immediate children will be iterated.

        :param root_asset_id: The root_asset_id of this SwapAcrossAssetsSearchV1.
        :type: str
        """

        self._root_asset_id = root_asset_id

    @property
    def search_type(self):
        """
        Gets the search_type of this SwapAcrossAssetsSearchV1.
        The type of finder

        :return: The search_type of this SwapAcrossAssetsSearchV1.
        :rtype: str
        """
        return self._search_type

    @search_type.setter
    def search_type(self, search_type):
        """
        Sets the search_type of this SwapAcrossAssetsSearchV1.
        The type of finder

        :param search_type: The search_type of this SwapAcrossAssetsSearchV1.
        :type: str
        """
        if search_type is None:
            raise ValueError("Invalid value for `search_type`, must not be `None`")
        allowed_values = ["SWAP_ACROSS_ASSETS", "FIXED_LIST", "PROPERTY", "MATERIALIZED_TABLE_UUID_COLUMN"]
        if search_type not in allowed_values:
            raise ValueError(
                "Invalid value for `search_type` ({0}), must be one of {1}"
                .format(search_type, allowed_values)
            )

        self._search_type = search_type

    @property
    def swap_item_id(self):
        """
        Gets the swap_item_id of this SwapAcrossAssetsSearchV1.
        Used if finder type is SwapAcrossAssets, this specifies the ID of the formula item that will be swapped with each asset beneath the root. Each successful swap will be added to the list of found items

        :return: The swap_item_id of this SwapAcrossAssetsSearchV1.
        :rtype: str
        """
        return self._swap_item_id

    @swap_item_id.setter
    def swap_item_id(self, swap_item_id):
        """
        Sets the swap_item_id of this SwapAcrossAssetsSearchV1.
        Used if finder type is SwapAcrossAssets, this specifies the ID of the formula item that will be swapped with each asset beneath the root. Each successful swap will be added to the list of found items

        :param swap_item_id: The swap_item_id of this SwapAcrossAssetsSearchV1.
        :type: str
        """

        self._swap_item_id = swap_item_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SwapAcrossAssetsSearchV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class GraphQLInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query': 'str',
        'variables': 'dict(str, object)'
    }

    attribute_map = {
        'query': 'query',
        'variables': 'variables'
    }

    def __init__(self, query=None, variables=None):
        """
        GraphQLInputV1 - a model defined in Swagger
        """

        self._query = None
        self._variables = None

        if query is not None:
          self.query = query
        if variables is not None:
          self.variables = variables

    @property
    def query(self):
        """
        Gets the query of this GraphQLInputV1.
        GraphQL query

        :return: The query of this GraphQLInputV1.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this GraphQLInputV1.
        GraphQL query

        :param query: The query of this GraphQLInputV1.
        :type: str
        """

        self._query = query

    @property
    def variables(self):
        """
        Gets the variables of this GraphQLInputV1.
        Variable substitutions for the query

        :return: The variables of this GraphQLInputV1.
        :rtype: dict(str, object)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this GraphQLInputV1.
        Variable substitutions for the query

        :param variables: The variables of this GraphQLInputV1.
        :type: dict(str, object)
        """

        self._variables = variables

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GraphQLInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DatasourceSummaryStatusOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_requests': 'bool',
        'average_indexing_duration': 'int',
        'cache_enabled': 'bool',
        'connections': 'list[ConnectionStatusOutputV1]',
        'connections_connected_count': 'int',
        'current_index_at': 'str',
        'current_indexing_duration': 'int',
        'current_indexing_mode': 'str',
        'current_indexing_percentage': 'int',
        'current_indexing_started_at': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'datasource_labels': 'str',
        'id': 'str',
        'indexing_schedule_supported': 'bool',
        'local_datasource': 'bool',
        'name': 'str',
        'next_scheduled_index_at': 'str',
        'placeholder': 'bool',
        'previous_index_at': 'str',
        'remaining_indexing_duration': 'int',
        'sync_progress': 'SyncProgressOutputV1',
        'sync_status': 'str',
        'total_connections_count': 'int'
    }

    attribute_map = {
        'allow_requests': 'allowRequests',
        'average_indexing_duration': 'averageIndexingDuration',
        'cache_enabled': 'cacheEnabled',
        'connections': 'connections',
        'connections_connected_count': 'connectionsConnectedCount',
        'current_index_at': 'currentIndexAt',
        'current_indexing_duration': 'currentIndexingDuration',
        'current_indexing_mode': 'currentIndexingMode',
        'current_indexing_percentage': 'currentIndexingPercentage',
        'current_indexing_started_at': 'currentIndexingStartedAt',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'datasource_labels': 'datasourceLabels',
        'id': 'id',
        'indexing_schedule_supported': 'indexingScheduleSupported',
        'local_datasource': 'localDatasource',
        'name': 'name',
        'next_scheduled_index_at': 'nextScheduledIndexAt',
        'placeholder': 'placeholder',
        'previous_index_at': 'previousIndexAt',
        'remaining_indexing_duration': 'remainingIndexingDuration',
        'sync_progress': 'syncProgress',
        'sync_status': 'syncStatus',
        'total_connections_count': 'totalConnectionsCount'
    }

    def __init__(self, allow_requests=False, average_indexing_duration=None, cache_enabled=False, connections=None, connections_connected_count=None, current_index_at=None, current_indexing_duration=None, current_indexing_mode=None, current_indexing_percentage=None, current_indexing_started_at=None, datasource_class=None, datasource_id=None, datasource_labels=None, id=None, indexing_schedule_supported=False, local_datasource=None, name=None, next_scheduled_index_at=None, placeholder=False, previous_index_at=None, remaining_indexing_duration=None, sync_progress=None, sync_status=None, total_connections_count=None):
        """
        DatasourceSummaryStatusOutputV1 - a model defined in Swagger
        """

        self._allow_requests = None
        self._average_indexing_duration = None
        self._cache_enabled = None
        self._connections = None
        self._connections_connected_count = None
        self._current_index_at = None
        self._current_indexing_duration = None
        self._current_indexing_mode = None
        self._current_indexing_percentage = None
        self._current_indexing_started_at = None
        self._datasource_class = None
        self._datasource_id = None
        self._datasource_labels = None
        self._id = None
        self._indexing_schedule_supported = None
        self._local_datasource = None
        self._name = None
        self._next_scheduled_index_at = None
        self._placeholder = None
        self._previous_index_at = None
        self._remaining_indexing_duration = None
        self._sync_progress = None
        self._sync_status = None
        self._total_connections_count = None

        if allow_requests is not None:
          self.allow_requests = allow_requests
        if average_indexing_duration is not None:
          self.average_indexing_duration = average_indexing_duration
        if cache_enabled is not None:
          self.cache_enabled = cache_enabled
        if connections is not None:
          self.connections = connections
        if connections_connected_count is not None:
          self.connections_connected_count = connections_connected_count
        if current_index_at is not None:
          self.current_index_at = current_index_at
        if current_indexing_duration is not None:
          self.current_indexing_duration = current_indexing_duration
        if current_indexing_mode is not None:
          self.current_indexing_mode = current_indexing_mode
        if current_indexing_percentage is not None:
          self.current_indexing_percentage = current_indexing_percentage
        if current_indexing_started_at is not None:
          self.current_indexing_started_at = current_indexing_started_at
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if datasource_labels is not None:
          self.datasource_labels = datasource_labels
        if id is not None:
          self.id = id
        if indexing_schedule_supported is not None:
          self.indexing_schedule_supported = indexing_schedule_supported
        if local_datasource is not None:
          self.local_datasource = local_datasource
        if name is not None:
          self.name = name
        if next_scheduled_index_at is not None:
          self.next_scheduled_index_at = next_scheduled_index_at
        if placeholder is not None:
          self.placeholder = placeholder
        if previous_index_at is not None:
          self.previous_index_at = previous_index_at
        if remaining_indexing_duration is not None:
          self.remaining_indexing_duration = remaining_indexing_duration
        if sync_progress is not None:
          self.sync_progress = sync_progress
        if sync_status is not None:
          self.sync_status = sync_status
        if total_connections_count is not None:
          self.total_connections_count = total_connections_count

    @property
    def allow_requests(self):
        """
        Gets the allow_requests of this DatasourceSummaryStatusOutputV1.
        Whether Seeq allows requests to the datasource

        :return: The allow_requests of this DatasourceSummaryStatusOutputV1.
        :rtype: bool
        """
        return self._allow_requests

    @allow_requests.setter
    def allow_requests(self, allow_requests):
        """
        Sets the allow_requests of this DatasourceSummaryStatusOutputV1.
        Whether Seeq allows requests to the datasource

        :param allow_requests: The allow_requests of this DatasourceSummaryStatusOutputV1.
        :type: bool
        """

        self._allow_requests = allow_requests

    @property
    def average_indexing_duration(self):
        """
        Gets the average_indexing_duration of this DatasourceSummaryStatusOutputV1.
        The duration in nanoseconds that indexing is expected to take, obtained via the average of the last 10 successful indexing durations, with null indicating no previous successful indexes

        :return: The average_indexing_duration of this DatasourceSummaryStatusOutputV1.
        :rtype: int
        """
        return self._average_indexing_duration

    @average_indexing_duration.setter
    def average_indexing_duration(self, average_indexing_duration):
        """
        Sets the average_indexing_duration of this DatasourceSummaryStatusOutputV1.
        The duration in nanoseconds that indexing is expected to take, obtained via the average of the last 10 successful indexing durations, with null indicating no previous successful indexes

        :param average_indexing_duration: The average_indexing_duration of this DatasourceSummaryStatusOutputV1.
        :type: int
        """

        self._average_indexing_duration = average_indexing_duration

    @property
    def cache_enabled(self):
        """
        Gets the cache_enabled of this DatasourceSummaryStatusOutputV1.
        Whether Cache is enabled for the datasource

        :return: The cache_enabled of this DatasourceSummaryStatusOutputV1.
        :rtype: bool
        """
        return self._cache_enabled

    @cache_enabled.setter
    def cache_enabled(self, cache_enabled):
        """
        Sets the cache_enabled of this DatasourceSummaryStatusOutputV1.
        Whether Cache is enabled for the datasource

        :param cache_enabled: The cache_enabled of this DatasourceSummaryStatusOutputV1.
        :type: bool
        """

        self._cache_enabled = cache_enabled

    @property
    def connections(self):
        """
        Gets the connections of this DatasourceSummaryStatusOutputV1.
        The status for each connection that provides data to this datasource. Provided only when the required level of detail is 'Complete'

        :return: The connections of this DatasourceSummaryStatusOutputV1.
        :rtype: list[ConnectionStatusOutputV1]
        """
        return self._connections

    @connections.setter
    def connections(self, connections):
        """
        Sets the connections of this DatasourceSummaryStatusOutputV1.
        The status for each connection that provides data to this datasource. Provided only when the required level of detail is 'Complete'

        :param connections: The connections of this DatasourceSummaryStatusOutputV1.
        :type: list[ConnectionStatusOutputV1]
        """

        self._connections = connections

    @property
    def connections_connected_count(self):
        """
        Gets the connections_connected_count of this DatasourceSummaryStatusOutputV1.
        Number of connections in status 'Connected' providing data for this datasource

        :return: The connections_connected_count of this DatasourceSummaryStatusOutputV1.
        :rtype: int
        """
        return self._connections_connected_count

    @connections_connected_count.setter
    def connections_connected_count(self, connections_connected_count):
        """
        Sets the connections_connected_count of this DatasourceSummaryStatusOutputV1.
        Number of connections in status 'Connected' providing data for this datasource

        :param connections_connected_count: The connections_connected_count of this DatasourceSummaryStatusOutputV1.
        :type: int
        """

        self._connections_connected_count = connections_connected_count

    @property
    def current_index_at(self):
        """
        Gets the current_index_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when current index occurred (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The current_index_at of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._current_index_at

    @current_index_at.setter
    def current_index_at(self, current_index_at):
        """
        Sets the current_index_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when current index occurred (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param current_index_at: The current_index_at of this DatasourceSummaryStatusOutputV1.
        :type: str
        """

        self._current_index_at = current_index_at

    @property
    def current_indexing_duration(self):
        """
        Gets the current_indexing_duration of this DatasourceSummaryStatusOutputV1.
        The duration in nanoseconds from when indexing started to the present time, if indexing is currently occurring

        :return: The current_indexing_duration of this DatasourceSummaryStatusOutputV1.
        :rtype: int
        """
        return self._current_indexing_duration

    @current_indexing_duration.setter
    def current_indexing_duration(self, current_indexing_duration):
        """
        Sets the current_indexing_duration of this DatasourceSummaryStatusOutputV1.
        The duration in nanoseconds from when indexing started to the present time, if indexing is currently occurring

        :param current_indexing_duration: The current_indexing_duration of this DatasourceSummaryStatusOutputV1.
        :type: int
        """

        self._current_indexing_duration = current_indexing_duration

    @property
    def current_indexing_mode(self):
        """
        Gets the current_indexing_mode of this DatasourceSummaryStatusOutputV1.
        The mode of the current indexing (FULL or INCREMENTAL)

        :return: The current_indexing_mode of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._current_indexing_mode

    @current_indexing_mode.setter
    def current_indexing_mode(self, current_indexing_mode):
        """
        Sets the current_indexing_mode of this DatasourceSummaryStatusOutputV1.
        The mode of the current indexing (FULL or INCREMENTAL)

        :param current_indexing_mode: The current_indexing_mode of this DatasourceSummaryStatusOutputV1.
        :type: str
        """

        self._current_indexing_mode = current_indexing_mode

    @property
    def current_indexing_percentage(self):
        """
        Gets the current_indexing_percentage of this DatasourceSummaryStatusOutputV1.
        The ratio of currentIndexingDuration to averageIndexingDuration, expressed as a percentage and rounded to the nearest integer

        :return: The current_indexing_percentage of this DatasourceSummaryStatusOutputV1.
        :rtype: int
        """
        return self._current_indexing_percentage

    @current_indexing_percentage.setter
    def current_indexing_percentage(self, current_indexing_percentage):
        """
        Sets the current_indexing_percentage of this DatasourceSummaryStatusOutputV1.
        The ratio of currentIndexingDuration to averageIndexingDuration, expressed as a percentage and rounded to the nearest integer

        :param current_indexing_percentage: The current_indexing_percentage of this DatasourceSummaryStatusOutputV1.
        :type: int
        """

        self._current_indexing_percentage = current_indexing_percentage

    @property
    def current_indexing_started_at(self):
        """
        Gets the current_indexing_started_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when the current indexing started, if indexing is currently occurring (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The current_indexing_started_at of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._current_indexing_started_at

    @current_indexing_started_at.setter
    def current_indexing_started_at(self, current_indexing_started_at):
        """
        Sets the current_indexing_started_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when the current indexing started, if indexing is currently occurring (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param current_indexing_started_at: The current_indexing_started_at of this DatasourceSummaryStatusOutputV1.
        :type: str
        """

        self._current_indexing_started_at = current_indexing_started_at

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this DatasourceSummaryStatusOutputV1.
        The datasource class.  Example: OSIsoft PI

        :return: The datasource_class of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this DatasourceSummaryStatusOutputV1.
        The datasource class.  Example: OSIsoft PI

        :param datasource_class: The datasource_class of this DatasourceSummaryStatusOutputV1.
        :type: str
        """
        if datasource_class is None:
            raise ValueError("Invalid value for `datasource_class`, must not be `None`")

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this DatasourceSummaryStatusOutputV1.
        The datasource ID

        :return: The datasource_id of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this DatasourceSummaryStatusOutputV1.
        The datasource ID

        :param datasource_id: The datasource_id of this DatasourceSummaryStatusOutputV1.
        :type: str
        """
        if datasource_id is None:
            raise ValueError("Invalid value for `datasource_id`, must not be `None`")

        self._datasource_id = datasource_id

    @property
    def datasource_labels(self):
        """
        Gets the datasource_labels of this DatasourceSummaryStatusOutputV1.
        Labels used for filtering datasources in the admin interface

        :return: The datasource_labels of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._datasource_labels

    @datasource_labels.setter
    def datasource_labels(self, datasource_labels):
        """
        Sets the datasource_labels of this DatasourceSummaryStatusOutputV1.
        Labels used for filtering datasources in the admin interface

        :param datasource_labels: The datasource_labels of this DatasourceSummaryStatusOutputV1.
        :type: str
        """

        self._datasource_labels = datasource_labels

    @property
    def id(self):
        """
        Gets the id of this DatasourceSummaryStatusOutputV1.
        The Seeq ID of the datasource

        :return: The id of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DatasourceSummaryStatusOutputV1.
        The Seeq ID of the datasource

        :param id: The id of this DatasourceSummaryStatusOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def indexing_schedule_supported(self):
        """
        Gets the indexing_schedule_supported of this DatasourceSummaryStatusOutputV1.
        Whether indexing schedule is supported for the datasource

        :return: The indexing_schedule_supported of this DatasourceSummaryStatusOutputV1.
        :rtype: bool
        """
        return self._indexing_schedule_supported

    @indexing_schedule_supported.setter
    def indexing_schedule_supported(self, indexing_schedule_supported):
        """
        Sets the indexing_schedule_supported of this DatasourceSummaryStatusOutputV1.
        Whether indexing schedule is supported for the datasource

        :param indexing_schedule_supported: The indexing_schedule_supported of this DatasourceSummaryStatusOutputV1.
        :type: bool
        """

        self._indexing_schedule_supported = indexing_schedule_supported

    @property
    def local_datasource(self):
        """
        Gets the local_datasource of this DatasourceSummaryStatusOutputV1.
        Whether the datasource is a local datasource

        :return: The local_datasource of this DatasourceSummaryStatusOutputV1.
        :rtype: bool
        """
        return self._local_datasource

    @local_datasource.setter
    def local_datasource(self, local_datasource):
        """
        Sets the local_datasource of this DatasourceSummaryStatusOutputV1.
        Whether the datasource is a local datasource

        :param local_datasource: The local_datasource of this DatasourceSummaryStatusOutputV1.
        :type: bool
        """

        self._local_datasource = local_datasource

    @property
    def name(self):
        """
        Gets the name of this DatasourceSummaryStatusOutputV1.
        The name of the datasource

        :return: The name of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DatasourceSummaryStatusOutputV1.
        The name of the datasource

        :param name: The name of this DatasourceSummaryStatusOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def next_scheduled_index_at(self):
        """
        Gets the next_scheduled_index_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when next indexing is scheduled (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The next_scheduled_index_at of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._next_scheduled_index_at

    @next_scheduled_index_at.setter
    def next_scheduled_index_at(self, next_scheduled_index_at):
        """
        Sets the next_scheduled_index_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when next indexing is scheduled (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param next_scheduled_index_at: The next_scheduled_index_at of this DatasourceSummaryStatusOutputV1.
        :type: str
        """

        self._next_scheduled_index_at = next_scheduled_index_at

    @property
    def placeholder(self):
        """
        Gets the placeholder of this DatasourceSummaryStatusOutputV1.
        Whether this is a placeholder datasource created for a connection without datasource

        :return: The placeholder of this DatasourceSummaryStatusOutputV1.
        :rtype: bool
        """
        return self._placeholder

    @placeholder.setter
    def placeholder(self, placeholder):
        """
        Sets the placeholder of this DatasourceSummaryStatusOutputV1.
        Whether this is a placeholder datasource created for a connection without datasource

        :param placeholder: The placeholder of this DatasourceSummaryStatusOutputV1.
        :type: bool
        """

        self._placeholder = placeholder

    @property
    def previous_index_at(self):
        """
        Gets the previous_index_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when previous index occurred (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The previous_index_at of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._previous_index_at

    @previous_index_at.setter
    def previous_index_at(self, previous_index_at):
        """
        Sets the previous_index_at of this DatasourceSummaryStatusOutputV1.
        The ISO 8601 date of when previous index occurred (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param previous_index_at: The previous_index_at of this DatasourceSummaryStatusOutputV1.
        :type: str
        """

        self._previous_index_at = previous_index_at

    @property
    def remaining_indexing_duration(self):
        """
        Gets the remaining_indexing_duration of this DatasourceSummaryStatusOutputV1.
        The difference between averageIndexingDuration and currentIndexingDuration, expressed in nanoseconds

        :return: The remaining_indexing_duration of this DatasourceSummaryStatusOutputV1.
        :rtype: int
        """
        return self._remaining_indexing_duration

    @remaining_indexing_duration.setter
    def remaining_indexing_duration(self, remaining_indexing_duration):
        """
        Sets the remaining_indexing_duration of this DatasourceSummaryStatusOutputV1.
        The difference between averageIndexingDuration and currentIndexingDuration, expressed in nanoseconds

        :param remaining_indexing_duration: The remaining_indexing_duration of this DatasourceSummaryStatusOutputV1.
        :type: int
        """

        self._remaining_indexing_duration = remaining_indexing_duration

    @property
    def sync_progress(self):
        """
        Gets the sync_progress of this DatasourceSummaryStatusOutputV1.

        :return: The sync_progress of this DatasourceSummaryStatusOutputV1.
        :rtype: SyncProgressOutputV1
        """
        return self._sync_progress

    @sync_progress.setter
    def sync_progress(self, sync_progress):
        """
        Sets the sync_progress of this DatasourceSummaryStatusOutputV1.

        :param sync_progress: The sync_progress of this DatasourceSummaryStatusOutputV1.
        :type: SyncProgressOutputV1
        """

        self._sync_progress = sync_progress

    @property
    def sync_status(self):
        """
        Gets the sync_status of this DatasourceSummaryStatusOutputV1.
        The aggregate synchronization status of the connections for this datasource

        :return: The sync_status of this DatasourceSummaryStatusOutputV1.
        :rtype: str
        """
        return self._sync_status

    @sync_status.setter
    def sync_status(self, sync_status):
        """
        Sets the sync_status of this DatasourceSummaryStatusOutputV1.
        The aggregate synchronization status of the connections for this datasource

        :param sync_status: The sync_status of this DatasourceSummaryStatusOutputV1.
        :type: str
        """
        allowed_values = ["SYNC_ARCHIVING_DELETED_ITEMS", "SYNC_IN_PROGRESS", "SYNC_INITIALIZING", "SYNC_SUCCESS", "SYNC_COMPLETE", "SYNC_FAILED", "SYNC_UNKNOWN"]
        if sync_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sync_status` ({0}), must be one of {1}"
                .format(sync_status, allowed_values)
            )

        self._sync_status = sync_status

    @property
    def total_connections_count(self):
        """
        Gets the total_connections_count of this DatasourceSummaryStatusOutputV1.
        The total number of connections that should be in status 'Connected' for this datasource

        :return: The total_connections_count of this DatasourceSummaryStatusOutputV1.
        :rtype: int
        """
        return self._total_connections_count

    @total_connections_count.setter
    def total_connections_count(self, total_connections_count):
        """
        Sets the total_connections_count of this DatasourceSummaryStatusOutputV1.
        The total number of connections that should be in status 'Connected' for this datasource

        :param total_connections_count: The total_connections_count of this DatasourceSummaryStatusOutputV1.
        :type: int
        """

        self._total_connections_count = total_connections_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DatasourceSummaryStatusOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
